@@ -29,5 +29,7 @@ License:
 """
 
 from .spectral_frequency_integrator import \
-    SpectralFrequencyIntegrator, \
-    create_table_from_textfiles
+    EmissivityIntegrator, \
+    add_xray_emissivity_field, \
+    add_xray_luminosity_field, \
+    add_xray_photon_emissivity_field
