@@ -31,12 +31,44 @@ import yt.utilities.lib as lib
 
 class UnilinearFieldInterpolator:
     def __init__(self, table, boundaries, field_names, truncate=False):
+        r"""Initialize a 1D interpolator for field data.
+
+        table : array
+            The data table over which interpolation is performed.
+        boundaries: tuple or array
+            If a tuple, this should specify the upper and lower bounds 
+            for the bins of the data table.  This assumes the bins are 
+            evenly spaced.  If an array, this specifies the bins 
+            explicitly.
+        field_names: str
+            Name of the field to be used as input data for interpolation.
+        truncate : bool
+            If False, an exception is raised if the input values are 
+            outside the bounds of the table.  If True, extrapolation is 
+            performed.
+        
+        Examples
+        --------
+
+        ad = pf.h.all_data()
+        table_data = np.random.random(64)
+        interp = UnilinearFieldInterpolator(table_data, (0.0, 1.0), "x",
+                                            truncate=True)
+        field_data = interp(ad)
+        
+        """
         self.table = table.astype('float64')
         self.truncate = truncate
-        x0, x1 = boundaries
         self.x_name = field_names
-        self.x_bins = np.linspace(x0, x1, table.shape[0]).astype('float64')
-
+        if isinstance(boundaries, np.ndarray):
+            if boundaries.size != table.shape[0]:
+                mylog.error("Bins array not the same length as the data.")
+                raise ValueError
+            self.x_bins = boundaries
+        else:
+            x0, x1 = boundaries
+            self.x_bins = np.linspace(x0, x1, table.shape[0]).astype('float64')
+        
     def __call__(self, data_object):
         orig_shape = data_object[self.x_name].shape
         x_vals = data_object[self.x_name].ravel().astype('float64')
@@ -57,12 +89,51 @@ class UnilinearFieldInterpolator:
 
 class BilinearFieldInterpolator:
     def __init__(self, table, boundaries, field_names, truncate=False):
+        r"""Initialize a 2D interpolator for field data.
+
+        table : array
+            The data table over which interpolation is performed.
+        boundaries: tuple
+            Either a tuple of lower and upper bounds for the x and y bins 
+            given as (x0, x1, y0, y1) or a tuple of two arrays containing the 
+            x and y bins.
+        field_names: list
+            Names of the fields to be used as input data for interpolation.
+        truncate : bool
+            If False, an exception is raised if the input values are 
+            outside the bounds of the table.  If True, extrapolation is 
+            performed.
+        
+        Examples
+        --------
+
+        ad = pf.h.all_data()
+        table_data = np.random.random((64, 64))
+        interp = BilinearFieldInterpolator(table_data, (0.0, 1.0, 0.0, 1.0), 
+                                           ["x", "y"],
+                                           truncate=True)
+        field_data = interp(ad)
+        
+        """
         self.table = table.astype('float64')
         self.truncate = truncate
-        x0, x1, y0, y1 = boundaries
         self.x_name, self.y_name = field_names
-        self.x_bins = np.linspace(x0, x1, table.shape[0]).astype('float64')
-        self.y_bins = np.linspace(y0, y1, table.shape[1]).astype('float64')
+        if len(boundaries) == 4:
+            x0, x1, y0, y1 = boundaries
+            self.x_bins = np.linspace(x0, x1, table.shape[0]).astype('float64')
+            self.y_bins = np.linspace(y0, y1, table.shape[1]).astype('float64')
+        elif len(boundaries) == 2:
+            if boundaries[0].size != table.shape[0]:
+                mylog.error("X bins array not the same length as the data.")
+                raise ValueError
+            if boundaries[1].size != table.shape[1]:
+                mylog.error("Y bins array not the same length as the data.")
+                raise ValueError
+            self.x_bins = boundaries[0]
+            self.y_bins = boundaries[1]
+        else:
+            mylog.error("Boundaries must be given as (x0, x1, y0, y1) or as (x_bins, y_bins)")
+            raise ValueError
 
     def __call__(self, data_object):
         orig_shape = data_object[self.x_name].shape
@@ -90,14 +161,58 @@ class BilinearFieldInterpolator:
 
 class TrilinearFieldInterpolator:
     def __init__(self, table, boundaries, field_names, truncate = False):
+        r"""Initialize a 3D interpolator for field data.
+
+        table : array
+            The data table over which interpolation is performed.
+        boundaries: tuple
+            Either a tuple of lower and upper bounds for the x, y, and z bins 
+            given as (x0, x1, y0, y1, z0, z1) or a tuple of three arrays 
+            containing the x, y, and z bins.
+        field_names: list
+            Names of the fields to be used as input data for interpolation.
+        truncate : bool
+            If False, an exception is raised if the input values are 
+            outside the bounds of the table.  If True, extrapolation is 
+            performed.
+        
+        Examples
+        --------
+
+        ad = pf.h.all_data()
+        table_data = np.random.random((64, 64, 64))
+        interp = BilinearFieldInterpolator(table_data, 
+                                           (0.0, 1.0, 0.0, 1.0, 0.0, 1.0), 
+                                           ["x", "y", "z"],
+                                           truncate=True)
+        field_data = interp(ad)
+        
+        """
         self.table = table.astype('float64')
         self.truncate = truncate
-        x0, x1, y0, y1, z0, z1 = boundaries
         self.x_name, self.y_name, self.z_name = field_names
-        self.x_bins = np.linspace(x0, x1, table.shape[0]).astype('float64')
-        self.y_bins = np.linspace(y0, y1, table.shape[1]).astype('float64')
-        self.z_bins = np.linspace(z0, z1, table.shape[2]).astype('float64')
-
+        if len(boundaries) == 6:
+            x0, x1, y0, y1, z0, z1 = boundaries
+            self.x_bins = np.linspace(x0, x1, table.shape[0]).astype('float64')
+            self.y_bins = np.linspace(y0, y1, table.shape[1]).astype('float64')
+            self.z_bins = np.linspace(z0, z1, table.shape[2]).astype('float64')
+        elif len(boundaries) == 3:
+            if boundaries[0].size != table.shape[0]:
+                mylog.error("X bins array not the same length as the data.")
+                raise ValueError
+            if boundaries[1].size != table.shape[1]:
+                mylog.error("Y bins array not the same length as the data.")
+                raise ValueError
+            if boundaries[2].size != table.shape[2]:
+                mylog.error("Z bins array not the same length as the data.")
+                raise ValueError
+            self.x_bins = boundaries[0]
+            self.y_bins = boundaries[1]
+            self.z_bins = boundaries[2]
+        else:
+            mylog.error("Boundaries must be given as (x0, x1, y0, y1, z0, z1) or as (x_bins, y_bins, z_bins)")
+            raise ValueError
+        
     def __call__(self, data_object):
         orig_shape = data_object[self.x_name].shape
         x_vals = data_object[self.x_name].ravel().astype('float64')
