@@ -34,7 +34,7 @@ def configuration(parent_package='', top_path=None):
 #                         libraries=libs,
 #                         **lapack)
 
-    config.add_extension('ckdtree', sources=['ckdtree.c'],
+    config.add_extension('ckdtree', sources=['ckdtree.pyx'],
         libraries=["m"],
         include_dirs=[get_numpy_include_dirs()])
 
