@@ -26,7 +26,7 @@ License:
 from matplotlib import figure
 import shutil
 import tempfile
-import numpy as na
+import numpy as np
 import os
 
 from yt.funcs import *
@@ -71,50 +71,49 @@ class ImageCollection(object):
 
     def add_image(self, fn, descr):
         self.image_metadata.append(descr)
-        self.images.append((os.path.basename(fn), na.fromfile(fn, dtype='c')))
+        self.images.append((os.path.basename(fn), np.fromfile(fn, dtype='c')))
 
 class PlotCollection(object):
+    r"""The PlotCollection object was created to ease the creation of multiple
+    slices, projections and so forth made from a single parameter file.
+    The concept is that when the width on one image changes, it should
+    change on all the others.  The PlotCollection can create all plot types
+    available in yt.
+
+    Parameters
+    ----------
+    pf : `StaticOutput`
+        The parameter file from which all the plots will be created.
+    center : array_like, optional
+        The 'center' supplied to plots like sphere plots, slices, and so
+        on.  Should be 3 elements.  Defaults to the point of maximum
+        density.
+    Long_variable_name : {'hi', 'ho'}, optional
+        Choices in brackets, default first when optional.
+
+    Notes
+    -----
+    This class is the primary entry point to creating plots, but it is not
+    the only entry point.  Additionally, creating a PlotCollection should
+    be a "cheap" operation.
+
+    You may iterate over the plots in the PlotCollection, via something
+    like:
+
+    >>> pc = PlotCollection(pf)
+    >>> for p in pc: print p
+
+    Examples
+    --------
+
+    >>> pc = PlotCollection(pf, center=[0.5, 0.5, 0.5])
+    >>> pc.add_slice("Density", 'x')
+    >>> pc.save()
+
+    """
+
     __id_counter = 0
     def __init__(self, pf, center=None):
-        r"""The primary interface for creating plots.
-
-        The PlotCollection object was created to ease the creation of multiple
-        slices, projections and so forth made from a single parameter file.
-        The concept is that when the width on one image changes, it should
-        change on all the others.  The PlotCollection can create all plot types
-        available in yt.
-
-        Parameters
-        ----------
-        pf : `StaticOutput`
-            The parameter file from which all the plots will be created.
-        center : array_like, optional
-            The 'center' supplied to plots like sphere plots, slices, and so
-            on.  Should be 3 elements.  Defaults to the point of maximum
-            density.
-        Long_variable_name : {'hi', 'ho'}, optional
-            Choices in brackets, default first when optional.
-
-        Notes
-        -----
-        This class is the primary entry point to creating plots, but it is not
-        the only entry point.  Additionally, creating a PlotCollection should
-        be a "cheap" operation.
-
-        You may iterate over the plots in the PlotCollection, via something
-        like:
-
-        >>> pc = PlotCollection(pf)
-        >>> for p in pc: print p
-
-        Examples
-        --------
-
-        >>> pc = PlotCollection(pf, center=[0.5, 0.5, 0.5])
-        >>> pc.add_slice("Density", 'x')
-        >>> pc.save()
-
-        """
         self.plots = []
         self.pf = pf
         if center == None:
@@ -122,7 +121,7 @@ class PlotCollection(object):
         elif center == "center" or center == "c":
             self.c = (pf.domain_right_edge + pf.domain_left_edge)/2.0
         else:
-            self.c = na.array(center, dtype='float64')
+            self.c = np.array(center, dtype='float64')
         mylog.info("Created plot collection with default plot-center = %s",
                     list(self.c))
 
@@ -1533,7 +1532,7 @@ class PlotCollection(object):
     @rootonly
     def save_book(self, filename, author = None, title = None, keywords = None,
                   subject = None, creator = None, producer = None,
-                  creation_data = None):
+                  creation_date = None):
         r"""Save a multipage PDF of all the current plots, rather than
         individual image files.
 
@@ -1580,15 +1579,21 @@ class PlotCollection(object):
         >>> dd = pf.h.all_data()
         >>> pc.add_phase_object(dd, ["Density", "Temperature", "CellMassMsun"],
         ...                     weight = None)
-        >>> pc.save_book("my_plots.pdf", author="Matthew Turk", 
+        >>> pc.save_book("my_plots.pdf", author="Yours Truly",
         ...              title="Fun plots")
         """
         from matplotlib.backends.backend_pdf import PdfPages
         outfile = PdfPages(filename)
         for plot in self.plots:
             plot.save_to_pdf(outfile)
-        if info is not None:
-            outfile._file.writeObject(outfile._file.infoObject, info)
+        pdf_keys = ['Title', 'Author', 'Subject', 'Keywords', 'Creator',
+            'Producer', 'CreationDate']
+        pdf_values = [title, author, subject, keywords, creator, producer,
+            creation_date]
+        metadata = outfile.infodict()
+        for key, val in zip(pdf_keys, pdf_values):
+            if isinstance(val, str):
+                metadata[key] = val
         outfile.close()
 
 def wrap_pylab_newplot(func):
@@ -1878,7 +1883,7 @@ def matplotlib_widget(data_source, field, npix):
         norm = matplotlib.colors.Normalize()
     ax = pylab.figure().gca()
     ax.autoscale(False)
-    axi = ax.imshow(na.random.random((npix, npix)),
+    axi = ax.imshow(np.random.random((npix, npix)),
                     extent = extent, norm = norm,
                     origin = 'lower')
     cb = pylab.colorbar(axi, norm = norm)
