@@ -7,7 +7,7 @@ Author: Nathan Goldbaum <goldbaum@ucolick.org>
 Affiliation: UCSC Astronomy
 Homepage: http://yt-project.org/
 License:
-  Copyright (C) 2010-2011 J. S. Oishi.  All Rights Reserved.
+  Copyright (C) 2010-2013 J. S. Oishi., Nathan Goldbaum  All Rights Reserved.
 
   This file is part of yt.
 
@@ -35,6 +35,7 @@ from matplotlib.mathtext import MathTextParser
 from matplotlib.font_manager import FontProperties
 from distutils import version
 from functools import wraps
+from numbers import Number
 
 from ._mpl_imports import \
     FigureCanvasAgg, FigureCanvasPdf, FigureCanvasPS
@@ -59,13 +60,13 @@ from yt.utilities.lib import write_png_to_string
 from yt.utilities.definitions import \
     x_dict, x_names, \
     y_dict, y_names, \
-    axis_names, \
-    axis_labels
+    axis_names, axis_labels, \
+    formatted_length_unit_names
 from yt.utilities.math_utils import \
     ortho_find
 from yt.utilities.parallel_tools.parallel_analysis_interface import \
     GroupOwnership
-from yt.utilities.exceptions import YTUnitNotRecognized
+from yt.utilities.exceptions import YTUnitNotRecognized, YTInvalidWidthError
 from yt.data_objects.time_series import \
     TimeSeriesData
 
@@ -152,6 +153,34 @@ class FieldTransform(object):
 log_transform = FieldTransform('log10', np.log10, LogLocator())
 linear_transform = FieldTransform('linear', lambda x: x, LinearLocator())
 
+def assert_valid_width_tuple(width):
+    try:
+        assert iterable(width) and len(width) == 2, \
+            "width (%s) is not a two element tuple" % width
+        valid = isinstance(width[0], Number) and isinstance(width[1], str)
+        msg = "width (%s) is invalid. " % str(width)
+        msg += "Valid widths look like this: (12, 'au')"
+        assert valid, msg
+    except AssertionError, e:
+        raise YTInvalidWidthError(e)
+
+def validate_iterable_width(width, unit=None):
+    if isinstance(width[0], tuple) and isinstance(width[1], tuple):
+        assert_valid_width_tuple(width[0])
+        assert_valid_width_tuple(width[1])
+        return width
+    elif isinstance(width[0], Number) and isinstance(width[1], Number):
+        return ((width[0], '1'), (width[1], '1'))
+    else:
+        assert_valid_width_tuple(width)
+        # If width and unit are both valid width tuples, we
+        # assume width controls x and unit controls y
+        try:
+            assert_valid_width_tuple(unit)
+            return (width, unit)
+        except YTInvalidWidthError:
+            return (width, width)
+
 def StandardWidth(axis, width, depth, pf):
     if width is None:
         # Default to code units
@@ -164,18 +193,23 @@ def StandardWidth(axis, width, depth, pf):
             width = ((pf.domain_width.min(), '1'),
                      (pf.domain_width.min(), '1'))
     elif iterable(width):
-        if isinstance(width[1], str):
-            width = (width, width)
-        elif isinstance(width[1], (long, int, float)):
-            width = ((width[0], '1'), (width[1], '1'))
+        width = validate_iterable_width(width)
     else:
+        try:
+            assert isinstance(width, Number), "width (%s) is invalid" % str(width)
+        except AssertionError, e:
+            raise YTInvalidWidthError(e)
         width = ((width, '1'), (width, '1'))
     if depth is not None:
         if iterable(depth) and isinstance(depth[1], str):
             depth = (depth,)
         elif iterable(depth):
-            raise RuntimeError("Depth must be a float or a (width,\"unit\") tuple")
+            assert_valid_width_tuple(depth)
         else:
+            try:
+                assert isinstance(depth, Number), "width (%s) is invalid" % str(depth)
+            except AssertionError, e:
+                raise YTInvalidWidthError(e)
             depth = ((depth, '1'),)
         width += depth
     return width
@@ -426,7 +460,7 @@ class PlotWindow(object):
 
         parameters
         ----------
-        width : float, array of floats, (float, unit) tuple, or arry of (float, unit) tuples.
+        width : float, array of floats, (float, unit) tuple, or tuple of (float, unit) tuples.
              Width can have four different formats to support windows with variable
              x and y widths.  They are:
 
@@ -447,18 +481,18 @@ class PlotWindow(object):
              in code units.  If units are provided the resulting plot axis labels will
              use the supplied units.
         unit : str
-             the unit the width has been specified in.
-             defaults to code units.  If width is a tuple this
-             argument is ignored
-
+             the unit the width has been specified in. If width is a tuple, this
+             argument is ignored. Defaults to code units.
         """
         if width is not None:
             set_axes_unit = True
         else:
             set_axes_unit = False
 
-        if isinstance(width, (int, long, float)):
+        if isinstance(width, Number):
             width = (width, unit)
+        elif iterable(width):
+            width = validate_iterable_width(width, unit)
 
         width = StandardWidth(self._frb.axis, width, None, self.pf)
 
@@ -551,8 +585,11 @@ class PWViewer(PlotWindow):
     """A viewer for PlotWindows.
 
     """
+    _plot_type = None
     def __init__(self, *args,**kwargs):
         setup = kwargs.pop("setup", True)
+        if self._plot_type is None:
+            self._plot_type = kwargs.pop("plot_type")
         PlotWindow.__init__(self, *args,**kwargs)
         self._axes_unit_names = None
         self._callbacks = []
@@ -635,7 +672,7 @@ class PWViewer(PlotWindow):
 
         Other Parameters
         ----------------
-        dyanmic_range : float (default: None)
+        dynamic_range : float (default: None)
             The dynamic range of the image.
             If zmin == None, will set zmin = zmax / dynamic_range
             If zmax == None, will set zmax = zmin * dynamic_range
@@ -740,6 +777,7 @@ class PWViewerMPL(PWViewer):
         font_size = kwargs.pop("fontsize", 18)
         font_path = matplotlib.get_data_path() + '/fonts/ttf/STIXGeneral.ttf'
         self._font_properties = FontProperties(size=font_size, fname=font_path)
+        self._font_color = None
         PWViewer.__init__(self, *args, **kwargs)
 
     def _setup_origin(self):
@@ -842,17 +880,23 @@ class PWViewerMPL(PWViewer):
 
             image = self._frb[f]
 
+            if image.max() == image.min() and self._field_transform[f] == log_transform:
+                mylog.warning("Plot image for field %s has zero dynamic " \
+                              "range. Min = Max = %d." % \
+                              (f, image.max()))
+                mylog.warning("Switching to linear colorbar scaling.")
+                self._field_transform[f] = linear_transform
+
             fp = self._font_properties
 
             self.plots[f] = WindowPlotMPL(image, self._field_transform[f].name,
                                           self._colormaps[f], extent, aspect,
                                           zlim, size, fp.get_size())
 
-            self.plots[f].cb = self.plots[f].figure.colorbar(
-                self.plots[f].image, cax = self.plots[f].cax)
-
             axes_unit_labels = ['', '']
             for i, un in enumerate((unit_x, unit_y)):
+                if un in formatted_length_unit_names:
+                    un = formatted_length_unit_names[un]
                 if un not in ['1', 'u', 'unitary']:
                     axes_unit_labels[i] = '\/\/('+un+')'
 
@@ -867,7 +911,9 @@ class PWViewerMPL(PWViewer):
             self.plots[f].axes.set_ylabel(labels[1],fontproperties=fp)
 
             for label in (self.plots[f].axes.get_xticklabels() +
-                          self.plots[f].axes.get_yticklabels()):
+                          self.plots[f].axes.get_yticklabels() +
+                          [self.plots[f].axes.xaxis.get_offset_text(),
+                           self.plots[f].axes.yaxis.get_offset_text()]):
                 label.set_fontproperties(fp)
 
             colorbar_label = image.info['label']
@@ -880,11 +926,24 @@ class PWViewerMPL(PWViewer):
 
             self.plots[f].cb.set_label(colorbar_label, fontproperties=fp)
 
-            for label in self.plots[f].cb.ax.get_yticklabels():
+            for label in (self.plots[f].cb.ax.get_xticklabels() +
+                          self.plots[f].cb.ax.get_yticklabels() +
+                          [self.plots[f].cb.ax.axes.xaxis.get_offset_text(),
+                           self.plots[f].cb.ax.axes.yaxis.get_offset_text()]):
                 label.set_fontproperties(fp)
 
             self.run_callbacks(f)
 
+            if self._font_color is not None:
+                ax = self.plots[f].axes
+                cbax = self.plots[f].cb.ax
+                labels = \
+                  ax.xaxis.get_ticklabels() + ax.yaxis.get_ticklabels() + \
+                  cbax.yaxis.get_ticklabels() + \
+                  [ax.xaxis.label, ax.yaxis.label, cbax.yaxis.label]
+                for label in labels:
+                    label.set_color(self._font_color)
+
         self._plot_valid = True
 
     def run_callbacks(self, f):
@@ -906,28 +965,49 @@ class PWViewerMPL(PWViewer):
         ----------
         font_dict : dict
         A dict of keyword parameters to be passed to
-        matplotlib.font_manager.FontProperties.  See the matplotlib font
-        manager documentation for more details.
+        :py:class:`matplotlib.font_manager.FontProperties`.
+
+        Possible keys include
+        * family - The font family. Can be serif, sans-serif, cursive, 'fantasy' or
+          'monospace'.
+        * style - The font style. Either normal, italic or oblique.
+        * color - A valid color string like 'r', 'g', 'red', 'cobalt', and
+          'orange'.
+        * variant: Either normal or small-caps.
+        * size: Either an relative value of xx-small, x-small, small, medium,
+          large, x-large, xx-large or an absolute font size, e.g. 12
+        * stretch: A numeric value in the range 0-1000 or one of
+          ultra-condensed, extra-condensed, condensed, semi-condensed, normal,
+          semi-expanded, expanded, extra-expanded or ultra-expanded
+        * weight: A numeric value in the range 0-1000 or one of ultralight,
+          light, normal, regular, book, medium, roman, semibold, demibold, demi,
+          bold, heavy, extra bold, or black
+
+        See the matplotlib font manager API documentation for more details.
         http://matplotlib.org/api/font_manager_api.html
 
         Notes
         -----
-        Mathtext axis labels will only obey the `size` keyword.
+        Mathtext axis labels will only obey the `size` and `color` keyword.
 
         Examples
         --------
-        This sets the font to be 24-pt, sans-serif, italic, and bold-face.
+        This sets the font to be 24-pt, blue, sans-serif, italic, and
+        bold-face.
 
         >>> slc = SlicePlot(pf, 'x', 'Density')
         >>> slc.set_font({'family':'sans-serif', 'style':'italic',
-                          'weight':'bold', 'size':24})
+                          'weight':'bold', 'size':24, 'color':'blue'})
 
         """
         if font_dict is None:
             font_dict = {}
+        if 'color' in font_dict:
+            self._font_color = font_dict.pop('color')
         self._font_properties = \
             FontProperties(**font_dict)
 
+
     @invalidate_plot
     def set_cmap(self, field, cmap):
         """set the colormap for one of the fields
@@ -1062,7 +1142,7 @@ class SlicePlot(PWViewerMPL):
     fields : string
          The name of the field(s) to be plotted.
     center : two or three-element vector of sequence floats, 'c', or 'center', or 'max'
-         The coordinate of the center of the image.  If left blanck,
+         The coordinate of the center of the image.  If left blank,
          the image centers on the location of the maximum density
          cell.  If set to 'c' or 'center', the plot is centered on
          the middle of the domain.  If set to 'max', will be at the point
@@ -1172,7 +1252,7 @@ class ProjectionPlot(PWViewerMPL):
     fields : string
         The name of the field(s) to be plotted.
     center : two or three-element vector of sequence floats, 'c', or 'center', or 'max'
-         The coordinate of the center of the image.  If left blanck,
+         The coordinate of the center of the image.  If left blank,
          the image centers on the location of the maximum density
          cell.  If set to 'c' or 'center', the plot is centered on
          the middle of the domain.  If set to 'max', will be at the point
@@ -1290,7 +1370,7 @@ class OffAxisSlicePlot(PWViewerMPL):
     fields : string
         The name of the field(s) to be plotted.
     center : A two or three-element vector of sequence floats, 'c', or 'center'
-        The coordinate of the center of the image.  If left blanck,
+        The coordinate of the center of the image.  If left blank,
         the image centers on the location of the maximum density
         cell.  If set to 'c' or 'center', the plot is centered on
         the middle of the domain.
@@ -1373,7 +1453,7 @@ class OffAxisProjectionPlot(PWViewerMPL):
     fields : string
         The name of the field(s) to be plotted.
     center : A two or three-element vector of sequence floats, 'c', or 'center'
-        The coordinate of the center of the image.  If left blanck,
+        The coordinate of the center of the image.  If left blank,
         the image centers on the location of the maximum density
         cell.  If set to 'c' or 'center', the plot is centered on
         the middle of the domain.
@@ -1687,6 +1767,10 @@ class WindowPlotMPL(ImagePlotMPL):
         ImagePlotMPL.__init__(self, fsize, axrect, caxrect, zlim)
         self._init_image(data, cbname, cmap, extent, aspect)
         self.image.axes.ticklabel_format(scilimits=(-2,3))
+        if cbname == 'linear':
+            self.cb.formatter.set_scientific(True)
+            self.cb.formatter.set_powerlimits((-2,3))
+            self.cb.update_ticks()
 
     def _get_best_layout(self, size, fontsize=18):
         aspect = 1.0*size[0]/size[1]
